==> hgubeta7.db_2.0.2.tar.gz: hgubeta7.db/man/hgubeta7_dbconn.Rd <==
\name{hgubeta7_dbconn}

\alias{hgubeta7_dbconn}
\alias{hgubeta7_dbfile}
\alias{hgubeta7_dbschema}
\alias{hgubeta7_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hgubeta7_dbconn()
  hgubeta7_dbfile()
  hgubeta7_dbschema(file="", show.indices=FALSE)
  hgubeta7_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hgubeta7_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{hgubeta7_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{hgubeta7_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hgubeta7_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hgubeta7_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hgubeta7_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{hgubeta7_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hgubeta7_dbschema}: none (invisible \code{NULL}).

  \code{hgubeta7_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hgubeta7_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hgubeta7_dbconn() was created with:
  dbConnect(SQLite(), dbname=hgubeta7_dbfile(), cache_size=64000, synchronous=0)

  hgubeta7_dbschema()

  hgubeta7_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> hgubeta7.db_3.0.0.tar.gz: hgubeta7.db/man/hgubeta7_dbconn.Rd <==

\name{hgubeta7_dbconn}

\alias{hgubeta7_dbconn}
\alias{hgubeta7_dbfile}
\alias{hgubeta7_dbschema}
\alias{hgubeta7_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hgubeta7_dbconn()
  hgubeta7_dbfile()
  hgubeta7_dbschema(file="", show.indices=FALSE)
  hgubeta7_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hgubeta7_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{hgubeta7_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{hgubeta7_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hgubeta7_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hgubeta7_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hgubeta7_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{hgubeta7_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hgubeta7_dbschema}: none (invisible \code{NULL}).

  \code{hgubeta7_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hgubeta7_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hgubeta7_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=hgubeta7_dbfile(), cache_size=64000,
  synchronous=0)

  hgubeta7_dbschema()

  hgubeta7_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
